InferenceClient

Struct InferenceClient 

pub struct InferenceClient { /* private fields */ }
Resource client for inference operations.

Requests use the untagged TermInputDto format. Use the psi, var, constrained, and guard builders to construct request payloads.

Implementations

Source

impl InferenceClient

pub async fn add_rule( &self, request: AddRuleRequest, options: Option<&RequestOptions>, ) -> Result<AddRuleResponse, Error>

Add an inference rule.

pub async fn add_fact( &self, request: AddFactRequest, options: Option<&RequestOptions>, ) -> Result<AddFactResponse, Error>

Add a fact.

pub async fn bulk_add_rules( &self, request: BulkAddRulesRequest, options: Option<&RequestOptions>, ) -> Result<BulkAddRulesResponse, Error>

Bulk-add rules.

pub async fn bulk_add_facts( &self, request: BulkAddFactsRequest, options: Option<&RequestOptions>, ) -> Result<BulkAddFactsResponse, Error>

Bulk-add facts.

pub async fn get_facts( &self, options: Option<&RequestOptions>, ) -> Result<GetFactsResponse, Error>

Get all stored facts for the tenant.

pub async fn clear_facts( &self, options: Option<&RequestOptions>, ) -> Result<ClearFactsResponse, Error>

Clear all stored facts for the tenant.

pub async fn backward_chain( &self, request: BackwardChainRequest, options: Option<&RequestOptions>, ) -> Result<BackwardChainResponse, Error>

Query for matching data by searching rules and facts backwards from a goal.

pub async fn forward_chain( &self, request: ForwardChainRequest, options: Option<&RequestOptions>, ) -> Result<ForwardChainResponse, Error>

Derive new facts by applying rules forward from existing facts.

pub async fn forward_chain_tagged( &self, request: TaggedForwardChainRequest, options: Option<&RequestOptions>, ) -> Result<TaggedForwardChainResponse, Error>

Forward chain with probabilistic provenance tags.

pub async fn fuzzy_prove( &self, request: FuzzyProveRequest, options: Option<&RequestOptions>, ) -> Result<FuzzyProveResponse, Error>

Fuzzy proof search.

pub async fn bulk_fuzzy_prove( &self, request: BulkFuzzyProveRequest, options: Option<&RequestOptions>, ) -> Result<BulkFuzzyProveResponse, Error>

Bulk fuzzy inference.

pub async fn bayesian_predict( &self, request: BayesianPredictRequest, options: Option<&RequestOptions>, ) -> Result<BayesianPredictResponse, Error>

Bayesian prediction.

pub async fn naf_prove( &self, request: NafProveRequest, options: Option<&RequestOptions>, ) -> Result<NafProveResponse, Error>

Negation-as-failure proof search.

pub async fn prove_with_negation( &self, request: NafProveRequest, options: Option<&RequestOptions>, ) -> Result<NafProveResponse, Error>

pub async fn create_goal( &self, request: CreateGoalRequest, options: Option<&RequestOptions>, ) -> Result<CreateGoalResponse, Error>

Create a saved goal for reuse.

pub async fn list_goals( &self, options: Option<&RequestOptions>, ) -> Result<ListGoalsResponse, Error>

List all saved goals.

pub async fn get_goal( &self, goal_id: &str, options: Option<&RequestOptions>, ) -> Result<PsiTermDto, Error>

Get a saved goal by ID.

pub async fn delete_goal( &self, goal_id: &str, options: Option<&RequestOptions>, ) -> Result<DeleteGoalResponse, Error>

Delete a saved goal.

pub async fn get_meta_sorts( &self, options: Option<&RequestOptions>, ) -> Result<MetaSortsResponse, Error>

Get meta-sorts used by the inference engine.

pub async fn query( &self, request: BackwardChainRequest, options: Option<&RequestOptions>, ) -> Result<BackwardChainResponse, Error>

pub async fn derive( &self, request: ForwardChainRequest, options: Option<&RequestOptions>, ) -> Result<ForwardChainResponse, Error>

pub async fn assert_fact( &self, request: AddFactRequest, options: Option<&RequestOptions>, ) -> Result<AddFactResponse, Error>